package com.antai.sport.http.server.server.api.business.traininglog.service;

import com.antai.sport.http.server.constants.DeleteStatus;
import com.antai.sport.http.server.constants.SportType;
import com.antai.sport.http.server.repository.sport.entity.SportUserSummary;
import com.antai.sport.http.server.repository.sport.entity.SportUserTrainingLog;
import com.antai.sport.http.server.repository.sport.mapper.SportUserSummaryMapper;
import com.antai.sport.http.server.repository.sport.mapper.SportUserTrainingLogMapper;
import com.antai.sport.http.server.server.api.business.traininglog.converter.SportUserTrainingLogConverter;
import com.antai.sport.http.server.server.api.common.dto.CyclingDataDTO;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

@Service
public class SportUserTrainingLogService {
    @Resource
    private SportUserTrainingLogMapper sportUserTrainingLogMapper;
    @Resource
    private SportUserSummaryMapper sportUserSummaryMapper;

    @Resource
    private SportUserTrainingLogConverter sportUserTrainingLogConverter;

    public void createBicycleTrainingLog(Long playerId, Integer gameMode, Long sourceId,
                                         String map, String path,
                                         Integer praiseNum, CyclingDataDTO sportData) {
        SportUserTrainingLog log = sportUserTrainingLogConverter.toSportUserTrainingLog(sportData);
        log.setSportType(SportType.BICYCLE);
        log.setGameMode(gameMode);
        log.setPlayerId(playerId);
        log.setSourceId(sourceId);
        log.setMap(map);
        log.setPath(path);
        log.setPraiseNum(praiseNum);
        log.setCreateTime(LocalDateTime.now());
        log.setCreateDate(LocalDate.now());
        sportUserTrainingLogMapper.insert(log);

        QueryWrapper<SportUserSummary> summaryQuery = new QueryWrapper<>();
        summaryQuery.eq("deleted", DeleteStatus.UNDELETED);
        summaryQuery.eq("user_id", playerId);
        summaryQuery.eq("type", SportType.BICYCLE);
        SportUserSummary summary = sportUserSummaryMapper.selectOne(summaryQuery);
        if (summary == null) {
            summary = new SportUserSummary();
            summary.setUserId(playerId);
            summary.setType( SportType.BICYCLE);
            summary.setTotalDistance(BigDecimal.ZERO);
            summary.setTotalClimbDistance(BigDecimal.ZERO);
            summary.setTotalDuration(0);
        }
        summary.setTotalDuration(summary.getTotalDuration() + log.getDuration());
        summary.setTotalDistance(summary.getTotalDistance().add(log.getDistance()));
        summary.setTotalClimbDistance(summary.getTotalClimbDistance().add(log.getClimbDistance()));
        if (summary.getId() == null) {
            sportUserSummaryMapper.insert(summary);
        } else {
            sportUserSummaryMapper.updateById(summary);
        }

    }
}
